==> arrow-docs-0.10.3-sources.jar: extension/arrow/aql/box/functor/BoxFunctor.kt <==
package arrow.aql.box.functor

import arrow.Kind
import arrow.aql.Box
import arrow.aql.Box.Companion
import arrow.aql.BoxFunctor
import arrow.aql.ForBox
import arrow.core.Tuple2
import kotlin.Function1
import kotlin.PublishedApi
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * cached extension
 */
@PublishedApi()
internal val functor_singleton: BoxFunctor = object : arrow.aql.BoxFunctor {}

@JvmName("map")
@Suppress(
    "UNCHECKED_CAST",
    "USELESS_CAST",
    "EXTENSION_SHADOWED_BY_MEMBER",
    "UNUSED_PARAMETER"
)
fun <A, B> Kind<ForBox, A>.map(arg1: Function1<A, B>): Box<B> = arrow.aql.Box.functor().run {
  this@map.map<A, B>(arg1) as arrow.aql.Box<B>
}

@JvmName("imap")
@Suppress(
    "UNCHECKED_CAST",
    "USELESS_CAST",
    "EXTENSION_SHADOWED_BY_MEMBER",
    "UNUSED_PARAMETER"
)
fun <A, B> Kind<ForBox, A>.imap(arg1: Function1<A, B>, arg2: Function1<B, A>): Box<B> =
    arrow.aql.Box.functor().run {
  this@imap.imap<A, B>(arg1, arg2) as arrow.aql.Box<B>
}

@JvmName("lift")
@Suppress(
    "UNCHECKED_CAST",
    "USELESS_CAST",
    "EXTENSION_SHADOWED_BY_MEMBER",
    "UNUSED_PARAMETER"
)
fun <A, B> lift(arg0: Function1<A, B>): Function1<Kind<ForBox, A>, Kind<ForBox, B>> = arrow.aql.Box
   .functor()
   .lift<A, B>(arg0) as kotlin.Function1<arrow.Kind<arrow.aql.ForBox, A>,
    arrow.Kind<arrow.aql.ForBox, B>>

@JvmName("unit")
@Suppress(
    "UNCHECKED_CAST",
    "USELESS_CAST",
    "EXTENSION_SHADOWED_BY_MEMBER",
    "UNUSED_PARAMETER"
)
fun <A> Kind<ForBox, A>.unit(): Box<Unit> = arrow.aql.Box.functor().run {
  this@unit.unit<A>() as arrow.aql.Box<kotlin.Unit>
}

@JvmName("fproduct")
@Suppress(
    "UNCHECKED_CAST",
    "USELESS_CAST",
    "EXTENSION_SHADOWED_BY_MEMBER",
    "UNUSED_PARAMETER"
)
fun <A, B> Kind<ForBox, A>.fproduct(arg1: Function1<A, B>): Box<Tuple2<A, B>> =
    arrow.aql.Box.functor().run {
  this@fproduct.fproduct<A, B>(arg1) as arrow.aql.Box<arrow.core.Tuple2<A, B>>
}

@JvmName("as")
@Suppress(
    "UNCHECKED_CAST",
    "USELESS_CAST",
    "EXTENSION_SHADOWED_BY_MEMBER",
    "UNUSED_PARAMETER"
)
fun <A, B> Kind<ForBox, A>.`as`(arg1: B): Box<B> = arrow.aql.Box.functor().run {
  this@`as`.`as`<A, B>(arg1) as arrow.aql.Box<B>
}

@JvmName("tupleLeft")
@Suppress(
    "UNCHECKED_CAST",
    "USELESS_CAST",
    "EXTENSION_SHADOWED_BY_MEMBER",
    "UNUSED_PARAMETER"
)
fun <A, B> Kind<ForBox, A>.tupleLeft(arg1: B): Box<Tuple2<B, A>> = arrow.aql.Box.functor().run {
  this@tupleLeft.tupleLeft<A, B>(arg1) as arrow.aql.Box<arrow.core.Tuple2<B, A>>
}

@JvmName("tupleRight")
@Suppress(
    "UNCHECKED_CAST",
    "USELESS_CAST",
    "EXTENSION_SHADOWED_BY_MEMBER",
    "UNUSED_PARAMETER"
)
fun <A, B> Kind<ForBox, A>.tupleRight(arg1: B): Box<Tuple2<A, B>> = arrow.aql.Box.functor().run {
  this@tupleRight.tupleRight<A, B>(arg1) as arrow.aql.Box<arrow.core.Tuple2<A, B>>
}

@JvmName("widen")
@Suppress(
    "UNCHECKED_CAST",
    "USELESS_CAST",
    "EXTENSION_SHADOWED_BY_MEMBER",
    "UNUSED_PARAMETER"
)
fun <B, A : B> Kind<ForBox, A>.widen(): Box<B> = arrow.aql.Box.functor().run {
  this@widen.widen<B, A>() as arrow.aql.Box<B>
}

@Suppress(
    "UNCHECKED_CAST",
    "NOTHING_TO_INLINE"
)
inline fun Companion.functor(): BoxFunctor = functor_singleton

==> arrow-docs-0.10.4-sources.jar: extension/arrow/aql/box/functor/BoxFunctor.kt <==
package arrow.aql.box.functor

import arrow.Kind
import arrow.aql.Box
import arrow.aql.Box.Companion
import arrow.aql.BoxFunctor
import arrow.aql.ForBox
import arrow.core.Tuple2
import kotlin.Function1
import kotlin.PublishedApi
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * cached extension
 */
@PublishedApi()
internal val functor_singleton: BoxFunctor = object : arrow.aql.BoxFunctor {}

@JvmName("map")
@Suppress(
    "UNCHECKED_CAST",
    "USELESS_CAST",
    "EXTENSION_SHADOWED_BY_MEMBER",
    "UNUSED_PARAMETER"
)
fun <A, B> Kind<ForBox, A>.map(arg1: Function1<A, B>): Box<B> = arrow.aql.Box.functor().run {
  this@map.map<A, B>(arg1) as arrow.aql.Box<B>
}

@JvmName("imap")
@Suppress(
    "UNCHECKED_CAST",
    "USELESS_CAST",
    "EXTENSION_SHADOWED_BY_MEMBER",
    "UNUSED_PARAMETER"
)
fun <A, B> Kind<ForBox, A>.imap(arg1: Function1<A, B>, arg2: Function1<B, A>): Box<B> =
    arrow.aql.Box.functor().run {
  this@imap.imap<A, B>(arg1, arg2) as arrow.aql.Box<B>
}

@JvmName("lift")
@Suppress(
    "UNCHECKED_CAST",
    "USELESS_CAST",
    "EXTENSION_SHADOWED_BY_MEMBER",
    "UNUSED_PARAMETER"
)
fun <A, B> lift(arg0: Function1<A, B>): Function1<Kind<ForBox, A>, Kind<ForBox, B>> = arrow.aql.Box
   .functor()
   .lift<A, B>(arg0) as kotlin.Function1<arrow.Kind<arrow.aql.ForBox, A>,
    arrow.Kind<arrow.aql.ForBox, B>>

@JvmName("unit")
@Suppress(
    "UNCHECKED_CAST",
    "USELESS_CAST",
    "EXTENSION_SHADOWED_BY_MEMBER",
    "UNUSED_PARAMETER"
)
fun <A> Kind<ForBox, A>.unit(): Box<Unit> = arrow.aql.Box.functor().run {
  this@unit.unit<A>() as arrow.aql.Box<kotlin.Unit>
}

@JvmName("fproduct")
@Suppress(
    "UNCHECKED_CAST",
    "USELESS_CAST",
    "EXTENSION_SHADOWED_BY_MEMBER",
    "UNUSED_PARAMETER"
)
fun <A, B> Kind<ForBox, A>.fproduct(arg1: Function1<A, B>): Box<Tuple2<A, B>> =
    arrow.aql.Box.functor().run {
  this@fproduct.fproduct<A, B>(arg1) as arrow.aql.Box<arrow.core.Tuple2<A, B>>
}

@JvmName("mapConst")
@Suppress(
    "UNCHECKED_CAST",
    "USELESS_CAST",
    "EXTENSION_SHADOWED_BY_MEMBER",
    "UNUSED_PARAMETER"
)
fun <A, B> Kind<ForBox, A>.mapConst(arg1: B): Box<B> = arrow.aql.Box.functor().run {
  this@mapConst.mapConst<A, B>(arg1) as arrow.aql.Box<B>
}

@JvmName("mapConst")
@Suppress(
    "UNCHECKED_CAST",
    "USELESS_CAST",
    "EXTENSION_SHADOWED_BY_MEMBER",
    "UNUSED_PARAMETER"
)
fun <A, B> A.mapConst(arg1: Kind<ForBox, B>): Box<A> = arrow.aql.Box.functor().run {
  this@mapConst.mapConst<A, B>(arg1) as arrow.aql.Box<A>
}

@JvmName("tupleLeft")
@Suppress(
    "UNCHECKED_CAST",
    "USELESS_CAST",
    "EXTENSION_SHADOWED_BY_MEMBER",
    "UNUSED_PARAMETER"
)
fun <A, B> Kind<ForBox, A>.tupleLeft(arg1: B): Box<Tuple2<B, A>> = arrow.aql.Box.functor().run {
  this@tupleLeft.tupleLeft<A, B>(arg1) as arrow.aql.Box<arrow.core.Tuple2<B, A>>
}

@JvmName("tupleRight")
@Suppress(
    "UNCHECKED_CAST",
    "USELESS_CAST",
    "EXTENSION_SHADOWED_BY_MEMBER",
    "UNUSED_PARAMETER"
)
fun <A, B> Kind<ForBox, A>.tupleRight(arg1: B): Box<Tuple2<A, B>> = arrow.aql.Box.functor().run {
  this@tupleRight.tupleRight<A, B>(arg1) as arrow.aql.Box<arrow.core.Tuple2<A, B>>
}

@JvmName("widen")
@Suppress(
    "UNCHECKED_CAST",
    "USELESS_CAST",
    "EXTENSION_SHADOWED_BY_MEMBER",
    "UNUSED_PARAMETER"
)
fun <B, A : B> Kind<ForBox, A>.widen(): Box<B> = arrow.aql.Box.functor().run {
  this@widen.widen<B, A>() as arrow.aql.Box<B>
}

@Suppress(
    "UNCHECKED_CAST",
    "NOTHING_TO_INLINE"
)
inline fun Companion.functor(): BoxFunctor = functor_singleton
